/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
/******/ 	var __webpack_modules__ = ({

/***/ 62:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.BacktraceClient = void 0;
const sdk_core_1 = __webpack_require__(668);
const path_1 = __importDefault(__webpack_require__(17));
const BacktraceNodeRequestHandler_1 = __webpack_require__(353);
const agentDefinition_1 = __webpack_require__(176);
const transformAttachments_1 = __webpack_require__(781);
const FileBreadcrumbsStorage_1 = __webpack_require__(582);
const BacktraceClientBuilder_1 = __webpack_require__(457);
const NodeOptionReader_1 = __webpack_require__(726);
const NodeDiagnosticReportConverter_1 = __webpack_require__(745);
const FsNodeFileSystem_1 = __webpack_require__(558);
class BacktraceClient extends sdk_core_1.BacktraceCoreClient {
    get nodeFileSystem() {
        return this.fileSystem;
    }
    constructor(clientSetup) {
        var _a, _b, _c, _d, _e;
        const fileSystem = (_a = clientSetup.fileSystem) !== null && _a !== void 0 ? _a : new FsNodeFileSystem_1.FsNodeFileSystem();
        super(Object.assign(Object.assign({ sdkOptions: agentDefinition_1.AGENT, requestHandler: new BacktraceNodeRequestHandler_1.BacktraceNodeRequestHandler(clientSetup.options), debugIdMapProvider: new sdk_core_1.VariableDebugIdMapProvider(global) }, clientSetup), { fileSystem, options: Object.assign(Object.assign({}, clientSetup.options), { attachments: (_b = clientSetup.options.attachments) === null || _b === void 0 ? void 0 : _b.map(transformAttachments_1.transformAttachment) }) }));
        this._listeners = {};
        const breadcrumbsManager = this.modules.get(sdk_core_1.BreadcrumbsManager);
        if (breadcrumbsManager && this.sessionFiles) {
            breadcrumbsManager.setStorage(FileBreadcrumbsStorage_1.FileBreadcrumbsStorage.create(this.sessionFiles, fileSystem, (_d = (_c = clientSetup.options.breadcrumbs) === null || _c === void 0 ? void 0 : _c.maximumBreadcrumbs) !== null && _d !== void 0 ? _d : 100));
        }
        if (this.sessionFiles && ((_e = clientSetup.options.database) === null || _e === void 0 ? void 0 : _e.captureNativeCrashes)) {
            this.addModule(sdk_core_1.FileAttributeManager, sdk_core_1.FileAttributeManager.create(fileSystem));
        }
    }
    initialize() {
        var _a, _b;
        const lockId = (_a = this.sessionFiles) === null || _a === void 0 ? void 0 : _a.lockPreviousSessions();
        try {
            super.initialize();
            this.captureUnhandledErrors(this.options.captureUnhandledErrors, this.options.captureUnhandledPromiseRejections);
            this.captureNodeCrashes();
        }
        catch (err) {
            lockId && ((_b = this.sessionFiles) === null || _b === void 0 ? void 0 : _b.unlockPreviousSessions(lockId));
            throw err;
        }
        this.loadNodeCrashes().finally(() => { var _a; return lockId && ((_a = this.sessionFiles) === null || _a === void 0 ? void 0 : _a.unlockPreviousSessions(lockId)); });
    }
    static builder(options) {
        return new BacktraceClientBuilder_1.BacktraceClientBuilder({ options });
    }
    /**
     * Initializes the client. If the client already exists, the available instance
     * will be returned and all other options will be ignored.
     * @param options client configuration
     * @param build builder
     * @returns backtrace client
     */
    static initialize(options, build) {
        if (this.instance) {
            return this.instance;
        }
        const builder = this.builder(options);
        build && build(builder);
        this._instance = builder.build();
        return this._instance;
    }
    /**
     * Returns created BacktraceClient instance if the instance exists.
     * Otherwise undefined.
     */
    static get instance() {
        return this._instance;
    }
    /**
     * Disposes the client and all client callbacks
     */
    dispose() {
        for (const [name, listener] of Object.entries(this._listeners)) {
            process.removeListener(name, listener);
        }
        super.dispose();
        BacktraceClient._instance = undefined;
    }
    captureUnhandledErrors(captureUnhandledExceptions = true, captureUnhandledRejections = true) {
        if (!captureUnhandledExceptions && !captureUnhandledRejections) {
            return;
        }
        const captureUncaughtException = (error, origin) => __awaiter(this, void 0, void 0, function* () {
            if (origin === 'unhandledRejection' && !captureUnhandledRejections) {
                return;
            }
            if (origin === 'uncaughtException' && !captureUnhandledExceptions) {
                return;
            }
            yield this.send(new sdk_core_1.BacktraceReport(error, { 'error.type': 'Unhandled exception', errorOrigin: origin }, [], {
                classifiers: origin === 'unhandledRejection' ? ['UnhandledPromiseRejection'] : undefined,
            }));
        });
        process.prependListener('uncaughtExceptionMonitor', captureUncaughtException);
        this._listeners['uncaughtExceptionMonitor'] = captureUncaughtException;
        if (!captureUnhandledRejections) {
            return;
        }
        // Node 15+ has changed the default unhandled promise rejection behavior.
        // In node 14 - the default behavior is to warn about unhandled promise rejections. In newer version
        // the default mode is throw.
        const nodeMajorVersion = process.version.split('.')[0];
        const unhandledRejectionMode = NodeOptionReader_1.NodeOptionReader.read('unhandled-rejections');
        const traceWarnings = NodeOptionReader_1.NodeOptionReader.read('trace-warnings');
        /**
         * Node JS allows to use only uncaughtExceptionMonitor only when:
         * - we're in the throw/strict error mode
         * - the node version 15+
         *
         * In other scenarios we need to capture unhandledRejections via other event.
         */
        const ignoreUnhandledRejectionHandler = unhandledRejectionMode === 'strict' ||
            unhandledRejectionMode === 'throw' ||
            (nodeMajorVersion !== 'v14' && !unhandledRejectionMode);
        if (ignoreUnhandledRejectionHandler) {
            return;
        }
        const captureUnhandledRejectionsCallback = (reason) => __awaiter(this, void 0, void 0, function* () {
            var _a, _b, _c, _d;
            const isErrorTypeReason = reason instanceof Error;
            yield this.send(new sdk_core_1.BacktraceReport(isErrorTypeReason ? reason : (_a = reason === null || reason === void 0 ? void 0 : reason.toString()) !== null && _a !== void 0 ? _a : 'Unhandled rejection', {
                'error.type': 'Unhandled exception',
            }, [], {
                classifiers: ['UnhandledPromiseRejection'],
                skipFrames: isErrorTypeReason ? 0 : 1,
            }));
            const error = isErrorTypeReason ? reason : new Error((_b = reason === null || reason === void 0 ? void 0 : reason.toString()) !== null && _b !== void 0 ? _b : 'Unhandled rejection');
            // if there is any other unhandled rejection handler, reproduce default node behavior
            // and let other handlers to capture the event
            if (process.listenerCount('unhandledRejection') !== 1) {
                return;
            }
            // everything else will be handled by node
            if (unhandledRejectionMode === 'none' || unhandledRejectionMode === 'warn') {
                return;
            }
            // handle last status: warn-with-error-code
            process.exitCode = 1;
            const unhandledRejectionErrName = 'UnhandledPromiseRejectionWarning';
            process.emitWarning((_c = (isErrorTypeReason ? error.stack : reason === null || reason === void 0 ? void 0 : reason.toString())) !== null && _c !== void 0 ? _c : '', unhandledRejectionErrName);
            const warning = new Error(`Unhandled promise rejection. This error originated either by ` +
                `throwing inside of an async function without a catch block, ` +
                `or by rejecting a promise which was not handled with .catch(). ` +
                `To terminate the node process on unhandled promise ` +
                'rejection, use the CLI flag `--unhandled-rejections=strict` (see ' +
                'https://nodejs.org/api/cli.html#cli_unhandled_rejections_mode). ');
            Object.defineProperty(warning, 'name', {
                value: 'UnhandledPromiseRejectionWarning',
                enumerable: false,
                writable: true,
                configurable: true,
            });
            warning.stack = traceWarnings && isErrorTypeReason ? (_d = error.stack) !== null && _d !== void 0 ? _d : '' : '';
            process.emitWarning(warning);
        });
        process.prependListener('unhandledRejection', captureUnhandledRejectionsCallback);
        this._listeners['unhandledRejection'] = captureUnhandledRejectionsCallback;
    }
    captureNodeCrashes() {
        var _a, _b;
        if (!process.report) {
            return;
        }
        if (!((_a = this.options.database) === null || _a === void 0 ? void 0 : _a.enable)) {
            return;
        }
        if (!((_b = this.options.database) === null || _b === void 0 ? void 0 : _b.captureNativeCrashes)) {
            return;
        }
        process.report.reportOnFatalError = true;
        if (!process.report.directory) {
            process.report.directory = this.options.database.path;
        }
    }
    loadNodeCrashes() {
        var _a, _b, _c, _d, _e, _f;
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.database || !this.nodeFileSystem || !((_a = this.options.database) === null || _a === void 0 ? void 0 : _a.captureNativeCrashes)) {
                return;
            }
            const reportName = (_b = process.report) === null || _b === void 0 ? void 0 : _b.filename;
            const databasePath = ((_c = process.report) === null || _c === void 0 ? void 0 : _c.directory)
                ? process.report.directory
                : (_e = (_d = this.options.database) === null || _d === void 0 ? void 0 : _d.path) !== null && _e !== void 0 ? _e : process.cwd();
            let databaseFiles;
            try {
                databaseFiles = yield this.nodeFileSystem.readDir(databasePath);
            }
            catch (_g) {
                return;
            }
            const converter = new NodeDiagnosticReportConverter_1.NodeDiagnosticReportConverter();
            const recordNames = databaseFiles.filter((file) => 
            // If the user specifies a preset name for reports, we should compare it directly
            // Otherwise, match the default name
            reportName ? file === reportName : file.startsWith('report.') && file.endsWith('.json'));
            if (!recordNames.length) {
                return;
            }
            const reports = [];
            for (const recordName of recordNames) {
                const recordPath = path_1.default.join(databasePath, recordName);
                try {
                    const recordJson = yield this.nodeFileSystem.readFile(recordPath);
                    const report = converter.convert(JSON.parse(recordJson));
                    reports.push([recordPath, report]);
                }
                catch (_h) {
                    // Do nothing, skip the report
                }
            }
            // Sort reports by timestamp descending
            reports.sort((a, b) => b[1].timestamp - a[1].timestamp);
            // Map reports to sessions
            // When the sessions are sorted by timestamp, we can assume that each previous session maps to the next report
            let currentSession = (_f = this.sessionFiles) === null || _f === void 0 ? void 0 : _f.getPreviousSession();
            for (const tuple of reports) {
                tuple[2] = currentSession;
                currentSession = currentSession === null || currentSession === void 0 ? void 0 : currentSession.getPreviousSession();
            }
            for (const [recordPath, report, session] of reports) {
                try {
                    if (session) {
                        const breadcrumbsStorage = FileBreadcrumbsStorage_1.FileBreadcrumbsStorage.createFromSession(session, this.nodeFileSystem);
                        if (breadcrumbsStorage) {
                            report.attachments.push(...breadcrumbsStorage.getAttachments());
                        }
                        const fileAttributes = sdk_core_1.FileAttributeManager.createFromSession(session, this.nodeFileSystem);
                        Object.assign(report.attributes, yield fileAttributes.get());
                        report.attributes['application.session'] = session.sessionId;
                    }
                    else {
                        report.attributes['application.session'] = null;
                    }
                    const data = this.generateSubmissionData(report);
                    if (data) {
                        this.database.add(data, report.attachments);
                    }
                }
                catch (_j) {
                    // Do nothing, skip the report
                }
                finally {
                    try {
                        yield this.nodeFileSystem.unlink(recordPath);
                    }
                    catch (_k) {
                        // Do nothing
                    }
                }
            }
            yield this.database.send();
        });
    }
}
exports.BacktraceClient = BacktraceClient;


/***/ }),

/***/ 47:
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));


/***/ }),

/***/ 353:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.BacktraceNodeRequestHandler = void 0;
const sdk_core_1 = __webpack_require__(668);
const form_data_1 = __importDefault(__webpack_require__(941));
const http_1 = __importDefault(__webpack_require__(685));
const https_1 = __importDefault(__webpack_require__(687));
class BacktraceNodeRequestHandler {
    constructor(_options) {
        var _a;
        this._options = _options;
        this.UPLOAD_FILE_NAME = 'upload_file';
        this.JSON_HEADERS = {
            'Content-type': 'application/json',
        };
        this._timeout = (_a = this._options.timeout) !== null && _a !== void 0 ? _a : sdk_core_1.DEFAULT_TIMEOUT;
    }
    postError(submissionUrl, dataJson, attachments, abortSignal) {
        return __awaiter(this, void 0, void 0, function* () {
            const formData = attachments.length === 0 ? dataJson : this.createFormData(dataJson, attachments);
            return this.send(submissionUrl, formData, abortSignal);
        });
    }
    post(submissionUrl, payload, abortSignal) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.send(submissionUrl, payload, abortSignal);
        });
    }
    send(submissionUrl, payload, abortSignal) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const url = new URL(submissionUrl);
                const httpClient = this.getHttpClient(url);
                return new Promise((res) => {
                    const request = httpClient.request(url, {
                        rejectUnauthorized: this._options.ignoreSslCertificate === true,
                        timeout: this._timeout,
                        method: 'POST',
                        headers: typeof payload === 'string' ? this.JSON_HEADERS : payload.getHeaders(),
                    }, (response) => {
                        let result = '';
                        response.on('data', (d) => {
                            result += d.toString();
                        });
                        response.on('end', () => {
                            switch (response.statusCode) {
                                case 200: {
                                    res(sdk_core_1.BacktraceReportSubmissionResult.Ok(JSON.parse(result)));
                                    break;
                                }
                                case 401:
                                case 403: {
                                    res(sdk_core_1.BacktraceReportSubmissionResult.OnInvalidToken());
                                    break;
                                }
                                case 429: {
                                    res(sdk_core_1.BacktraceReportSubmissionResult.OnLimitReached());
                                    break;
                                }
                                default: {
                                    res(sdk_core_1.BacktraceReportSubmissionResult.OnInternalServerError(result));
                                    break;
                                }
                            }
                            cleanup();
                        });
                        response.on('error', () => {
                            cleanup();
                        });
                    });
                    function abortFn() {
                        const reason = this.reason instanceof Error
                            ? this.reason
                            : typeof this.reason === 'string'
                                ? new Error(this.reason)
                                : new Error('Operation cancelled.');
                        request.destroy(reason);
                    }
                    abortSignal === null || abortSignal === void 0 ? void 0 : abortSignal.addEventListener('abort', abortFn, { once: true });
                    function cleanup() {
                        abortSignal === null || abortSignal === void 0 ? void 0 : abortSignal.removeEventListener('abort', cleanup);
                    }
                    request.on('error', (err) => {
                        cleanup();
                        if (sdk_core_1.ConnectionError.isConnectionError(err)) {
                            return res(sdk_core_1.BacktraceReportSubmissionResult.OnNetworkingError(err.message));
                        }
                        return res(sdk_core_1.BacktraceReportSubmissionResult.OnInternalServerError(err.message));
                    });
                    if (typeof payload === 'string') {
                        request.write(payload);
                        request.end();
                    }
                    else {
                        payload.pipe(request);
                    }
                });
            }
            catch (err) {
                if (sdk_core_1.ConnectionError.isConnectionError(err)) {
                    return sdk_core_1.BacktraceReportSubmissionResult.OnNetworkingError(err.message);
                }
                const errorMessage = err instanceof Error ? err.message : err;
                return sdk_core_1.BacktraceReportSubmissionResult.OnUnknownError(errorMessage);
            }
        });
    }
    getHttpClient(submissionUrl) {
        return submissionUrl.protocol === 'http' ? http_1.default : https_1.default;
    }
    createFormData(json, attachments) {
        const formData = new form_data_1.default();
        formData.append(this.UPLOAD_FILE_NAME, json, `${this.UPLOAD_FILE_NAME}.json`);
        if (!attachments || attachments.length === 0) {
            return formData;
        }
        for (const attachment of attachments) {
            const data = attachment.get();
            if (!data) {
                continue;
            }
            formData.append(`attachment_${attachment.name}`, data, attachment.name);
        }
        return formData;
    }
}
exports.BacktraceNodeRequestHandler = BacktraceNodeRequestHandler;


/***/ }),

/***/ 176:
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.AGENT = void 0;
exports.AGENT = {
    langName: 'nodejs',
    langVersion: process.version,
    /**
     * To do - in the build stage, we can inject information
     * about our package name and agent version. Since we don't have
     * it now, I'm leaving it hardcoded, but in the future we want
     * to change it and use webpack to generate it
     */
    agent: "@backtrace/node",
    agentVersion: "0.2.0",
};


/***/ }),

/***/ 388:
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.BacktraceBufferAttachment = void 0;
class BacktraceBufferAttachment {
    constructor(name, buffer) {
        this.name = name;
        this.buffer = buffer;
    }
    get() {
        return this.buffer;
    }
}
exports.BacktraceBufferAttachment = BacktraceBufferAttachment;


/***/ }),

/***/ 535:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.BacktraceFileAttachment = void 0;
const fs_1 = __importDefault(__webpack_require__(147));
const path_1 = __importDefault(__webpack_require__(17));
class BacktraceFileAttachment {
    constructor(filePath, name) {
        this.filePath = filePath;
        this.name = name !== null && name !== void 0 ? name : path_1.default.basename(this.filePath);
    }
    get() {
        if (!fs_1.default.existsSync(this.filePath)) {
            return undefined;
        }
        return fs_1.default.createReadStream(this.filePath);
    }
}
exports.BacktraceFileAttachment = BacktraceFileAttachment;


/***/ }),

/***/ 577:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.BacktraceUint8ArrayAttachment = exports.BacktraceStringAttachment = void 0;
var sdk_core_1 = __webpack_require__(668);
Object.defineProperty(exports, "BacktraceStringAttachment", ({ enumerable: true, get: function () { return sdk_core_1.BacktraceStringAttachment; } }));
Object.defineProperty(exports, "BacktraceUint8ArrayAttachment", ({ enumerable: true, get: function () { return sdk_core_1.BacktraceUint8ArrayAttachment; } }));
__exportStar(__webpack_require__(388), exports);
__exportStar(__webpack_require__(535), exports);


/***/ }),

/***/ 781:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.transformAttachment = void 0;
const BacktraceFileAttachment_1 = __webpack_require__(535);
/**
 * Transform a client attachment into the attachment model.
 */
function transformAttachment(attachment) {
    return typeof attachment === 'string'
        ? new BacktraceFileAttachment_1.BacktraceFileAttachment(attachment)
        : attachment;
}
exports.transformAttachment = transformAttachment;


/***/ }),

/***/ 523:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.ApplicationInformationAttributeProvider = void 0;
const fs_1 = __importDefault(__webpack_require__(147));
const path_1 = __importDefault(__webpack_require__(17));
const process_1 = __importDefault(__webpack_require__(369));
class ApplicationInformationAttributeProvider {
    get type() {
        return 'scoped';
    }
    constructor(applicationSearchPaths, nodeConfiguration) {
        var _a, _b;
        if (nodeConfiguration === void 0) { nodeConfiguration = {
            application: (_a = process_1.default.env) === null || _a === void 0 ? void 0 : _a.npm_package_name,
            version: (_b = process_1.default.env) === null || _b === void 0 ? void 0 : _b.npm_package_version,
        }; }
        this.APPLICATION_ATTRIBUTE = 'application';
        this.APPLICATION_VERSION_ATTRIBUTE = 'application.version';
        this._application = nodeConfiguration === null || nodeConfiguration === void 0 ? void 0 : nodeConfiguration.application;
        this._applicationVersion = nodeConfiguration === null || nodeConfiguration === void 0 ? void 0 : nodeConfiguration.version;
        this.applicationSearchPaths = applicationSearchPaths !== null && applicationSearchPaths !== void 0 ? applicationSearchPaths : this.generateDefaultApplicationSearchPaths();
    }
    get() {
        var _a, _b;
        const applicationData = this.readApplicationInformation();
        if (applicationData) {
            this._application = (_a = this._application) !== null && _a !== void 0 ? _a : applicationData['name'];
            this._applicationVersion = (_b = this._applicationVersion) !== null && _b !== void 0 ? _b : applicationData['version'];
        }
        if (!this._application || !this._applicationVersion) {
            throw new Error('Cannot find information about the package. Please define application and application.version attribute');
        }
        return {
            package: applicationData,
            [this.APPLICATION_ATTRIBUTE]: this._application,
            [this.APPLICATION_VERSION_ATTRIBUTE]: this._applicationVersion,
        };
    }
    generateDefaultApplicationSearchPaths() {
        var _a;
        const possibleSourcePaths = [process_1.default.cwd(), this.generatePathBasedOnTheDirName()];
        const potentialCommandLineStartupFile = process_1.default.argv[1];
        if (potentialCommandLineStartupFile) {
            const potentialCommandLineStartupFilePath = path_1.default.resolve(potentialCommandLineStartupFile);
            if (fs_1.default.existsSync(potentialCommandLineStartupFilePath)) {
                possibleSourcePaths.unshift(potentialCommandLineStartupFilePath);
            }
        }
        if ((_a = __webpack_require__.c[__webpack_require__.s]) === null || _a === void 0 ? void 0 : _a.path) {
            possibleSourcePaths.unshift(path_1.default.dirname(__webpack_require__.c[__webpack_require__.s].path));
        }
        return possibleSourcePaths;
    }
    generatePathBasedOnTheDirName() {
        const nodeModulesIndex = __dirname.lastIndexOf('node_modules');
        if (nodeModulesIndex === -1) {
            return __dirname;
        }
        return __dirname.substring(0, nodeModulesIndex);
    }
    readApplicationInformation() {
        for (let possibleSourcePath of this.applicationSearchPaths) {
            // to make sure we check all directories including `/` we want to assign the parent
            // directory to the current path after checking if the parent directory is equal the current
            // directory. Because of that in the while condition, there is an assignement to the
            // current directory to check next dir in the dir strucutre.
            do {
                const packageJson = this.readPackageFromDir(possibleSourcePath);
                if (packageJson) {
                    return packageJson;
                }
            } while (possibleSourcePath !== path_1.default.dirname(possibleSourcePath) &&
                (possibleSourcePath = path_1.default.dirname(possibleSourcePath)));
        }
    }
    readPackageFromDir(dirPath) {
        const packagePath = path_1.default.join(dirPath, 'package.json');
        if (!fs_1.default.existsSync(packagePath)) {
            return undefined;
        }
        return JSON.parse(fs_1.default.readFileSync(packagePath, 'utf8'));
    }
}
exports.ApplicationInformationAttributeProvider = ApplicationInformationAttributeProvider;


/***/ }),

/***/ 808:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.LinuxProcessStatusAttributeProvider = void 0;
const fs_1 = __importDefault(__webpack_require__(147));
const processStatusInformationMap_1 = __webpack_require__(396);
class LinuxProcessStatusAttributeProvider {
    constructor() {
        this._isLinux = process.platform === 'linux';
    }
    get type() {
        return this._isLinux ? 'dynamic' : 'scoped';
    }
    get() {
        if (!this._isLinux) {
            return {};
        }
        const memoryInformation = this.getMemoryInformation();
        const processInformation = this.getProcessStatus();
        return Object.assign(Object.assign({}, memoryInformation), processInformation);
    }
    getMemoryInformation() {
        const result = {};
        let file = '';
        try {
            file = fs_1.default.readFileSync('/proc/meminfo', { encoding: 'utf8' });
        }
        catch (err) {
            return {};
        }
        const lines = file.trim().split('\n');
        for (const line of lines) {
            const match = line.match(processStatusInformationMap_1.MEMORY_INFORMATION_REGEX);
            if (!match) {
                continue;
            }
            const name = match[1];
            const attrName = processStatusInformationMap_1.MEMORY_ATTRIBUTE_MAP[name];
            if (!attrName) {
                continue;
            }
            let number = parseInt(match[2], 10);
            const units = match[3];
            if (units === 'kB') {
                number *= 1024;
            }
            result[attrName] = number;
        }
        return result;
    }
    getProcessStatus() {
        // Justification for doing this synchronously:
        // * We need to collect this information in the process uncaughtException handler, in which the
        //   event loop is not safe to use.
        // * We are collecting a snapshot of virtual memory used. If this is done asynchronously, then
        //   we may pick up virtual memory information for a time different than the moment we are
        //   interested in.
        // * procfs is a virtual filesystem; there is no disk I/O to block on. It's synchronous anyway.
        let contents;
        try {
            contents = fs_1.default.readFileSync('/proc/self/status', { encoding: 'utf8' });
        }
        catch (err) {
            return {};
        }
        const result = {};
        for (let i = 0; i < processStatusInformationMap_1.PROCESS_STATUS_MAP.length; i += 1) {
            const item = processStatusInformationMap_1.PROCESS_STATUS_MAP[i];
            const match = contents.match(item.re);
            if (!match) {
                continue;
            }
            result[item.attr] = item.parse(match[1], 10);
        }
        return result;
    }
}
exports.LinuxProcessStatusAttributeProvider = LinuxProcessStatusAttributeProvider;


/***/ }),

/***/ 399:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.MachineAttributeProvider = void 0;
const os_1 = __importDefault(__webpack_require__(37));
class MachineAttributeProvider {
    get type() {
        return 'scoped';
    }
    get() {
        const cpus = os_1.default.cpus();
        return {
            'cpu.arch': os_1.default.arch(),
            'cpu.boottime': Math.floor(Date.now() / 1000) - os_1.default.uptime(),
            'cpu.count': cpus.length,
            'cpu.brand': cpus[0].model,
            'cpu.frequency': cpus[0].speed,
            'system.memory.total': os_1.default.totalmem(),
            hostname: os_1.default.hostname(),
            'uname.version': os_1.default.release(),
            'Environment Variables': process.env,
        };
    }
}
exports.MachineAttributeProvider = MachineAttributeProvider;


/***/ }),

/***/ 921:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.MachineIdentitfierAttributeProvider = void 0;
const sdk_core_1 = __webpack_require__(668);
const child_process_1 = __webpack_require__(81);
const native_reg_1 = __webpack_require__(877);
class MachineIdentitfierAttributeProvider {
    constructor() {
        this.MACHINE_ID_ATTRIBUTE = 'guid';
        this.COMMANDS = {
            darwin: 'ioreg -rd1 -c IOPlatformExpertDevice',
            linux: '( cat /var/lib/dbus/machine-id /etc/machine-id 2> /dev/null || hostname ) | head -n 1 || :',
            freebsd: 'kenv -q smbios.system.uuid || sysctl -n kern.hostuuid',
        };
    }
    get type() {
        return 'scoped';
    }
    get() {
        var _a;
        const guid = (_a = this.generateGuid()) !== null && _a !== void 0 ? _a : sdk_core_1.IdGenerator.uuid();
        return {
            [this.MACHINE_ID_ATTRIBUTE]: guid,
        };
    }
    generateGuid() {
        var _a;
        switch (process.platform) {
            case 'win32': {
                return (_a = this.getWindowsMachineId()) === null || _a === void 0 ? void 0 : _a.replace(/\r+|\n+|\s+/gi, '').toLowerCase();
            }
            case 'darwin': {
                return (0, child_process_1.execSync)(this.COMMANDS[process.platform])
                    .toString()
                    .split('IOPlatformUUID')[1]
                    .split('\n')[0]
                    .replace(/=|\s+|"/gi, '')
                    .toLowerCase();
            }
            case 'linux':
            case 'freebsd': {
                return (0, child_process_1.execSync)(this.COMMANDS[process.platform])
                    .toString()
                    .replace(/\r+|\n+|\s+/gi, '')
                    .toLowerCase();
            }
            default: {
                return null;
            }
        }
    }
    getWindowsMachineId() {
        const regVal = (0, native_reg_1.getValue)(native_reg_1.HKEY.LOCAL_MACHINE, 'SOFTWARE\\Microsoft\\Cryptography', 'MachineGuid');
        return regVal === null || regVal === void 0 ? void 0 : regVal.toString();
    }
}
exports.MachineIdentitfierAttributeProvider = MachineIdentitfierAttributeProvider;
MachineIdentitfierAttributeProvider.SUPPORTED_PLATFORMS = ['win32', 'darwin', 'linux', 'freebsd'];


/***/ }),

/***/ 358:
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.ProcessInformationAttributeProvider = void 0;
class ProcessInformationAttributeProvider {
    get type() {
        return 'scoped';
    }
    get() {
        return {
            'process.thread.count': 1,
            'process.cwd': process.cwd(),
            pid: process.pid,
            'uname.machine': process.arch,
            'uname.sysname': this.convertPlatformToAttribute(process.platform),
            environment: "production",
            'debug.port': process.debugPort,
            'Exec Arguments': process.execArgv,
        };
    }
    convertPlatformToAttribute(platform) {
        switch (platform) {
            case 'win32': {
                return 'Windows';
            }
            case 'darwin': {
                return 'Mac OS';
            }
            default: {
                return platform.charAt(0).toUpperCase() + platform.slice(1);
            }
        }
    }
}
exports.ProcessInformationAttributeProvider = ProcessInformationAttributeProvider;


/***/ }),

/***/ 867:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.ProcessStatusAttributeProvider = void 0;
const os_1 = __importDefault(__webpack_require__(37));
class ProcessStatusAttributeProvider {
    get type() {
        return 'dynamic';
    }
    get() {
        const processMemoryUsage = process.memoryUsage();
        const result = {
            'vm.rss.size': processMemoryUsage.rss,
            'gc.heap.total': processMemoryUsage.heapTotal,
            'gc.heap.used': processMemoryUsage.heapUsed,
            'process.age': Math.floor(process.uptime()),
            'system.memory.free': os_1.default.freemem(),
        };
        return result;
    }
}
exports.ProcessStatusAttributeProvider = ProcessStatusAttributeProvider;


/***/ }),

/***/ 816:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
__exportStar(__webpack_require__(523), exports);
__exportStar(__webpack_require__(808), exports);
__exportStar(__webpack_require__(399), exports);
__exportStar(__webpack_require__(921), exports);
__exportStar(__webpack_require__(358), exports);
__exportStar(__webpack_require__(867), exports);


/***/ }),

/***/ 396:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.PROCESS_STATUS_MAP = exports.MEMORY_ATTRIBUTE_MAP = exports.MEMORY_INFORMATION_REGEX = void 0;
const UnitConverter_1 = __webpack_require__(230);
exports.MEMORY_INFORMATION_REGEX = /^(.+):\s+(\d+)\s*(.+)?$/;
exports.MEMORY_ATTRIBUTE_MAP = {
    MemTotal: 'system.memory.total',
    MemFree: 'system.memory.free',
    MemAvailable: 'system.memory.available',
    Buffers: 'system.memory.buffers',
    Cached: 'system.memory.cached',
    SwapCached: 'system.memory.swap.cached',
    Active: 'system.memory.active',
    Inactive: 'system.memory.inactive',
    SwapTotal: 'system.memory.swap.total',
    SwapFree: 'system.memory.swap.free',
    Dirty: 'system.memory.dirty',
    Writeback: 'system.memory.writeback',
    Slab: 'system.memory.slab',
    VmallocTotal: 'system.memory.vmalloc.total',
    VmallocUsed: 'system.memory.vmalloc.used',
    VmallocChunk: 'system.memory.vmalloc.chunk',
};
exports.PROCESS_STATUS_MAP = [
    {
        re: /^nonvoluntary_ctxt_switches:\s+(\d+)$/m,
        parse: parseInt,
        attr: 'sched.cs.involuntary',
    },
    {
        re: /^voluntary_ctxt_switches:\s+(\d+)$/m,
        parse: parseInt,
        attr: 'sched.cs.voluntary',
    },
    { re: /^FDSize:\s+(\d+)$/m, parse: parseInt, attr: 'descriptor.count' },
    { re: /^FDSize:\s+(\d+)$/m, parse: parseInt, attr: 'descriptor.count' },
    { re: /^VmData:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.data.size' },
    { re: /^VmLck:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.locked.size' },
    { re: /^VmPTE:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.pte.size' },
    { re: /^VmHWM:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.rss.peak' },
    { re: /^VmRSS:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.rss.size' },
    { re: /^VmLib:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.shared.size' },
    { re: /^VmStk:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.stack.size' },
    { re: /^VmSwap:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.swap.size' },
    { re: /^VmPeak:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.vma.peak' },
    { re: /^VmSize:\s+(\d+)\s+kB$/m, parse: UnitConverter_1.UnitConverter.parseKb, attr: 'vm.vma.size' },
];


/***/ }),

/***/ 582:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.FileBreadcrumbsStorage = void 0;
const sdk_core_1 = __webpack_require__(668);
const path_1 = __importDefault(__webpack_require__(17));
const attachment_1 = __webpack_require__(577);
const AlternatingFileWriter_1 = __webpack_require__(636);
const FILE_PREFIX = 'breadcrumbs';
class FileBreadcrumbsStorage {
    get lastBreadcrumbId() {
        return this._lastBreadcrumbId;
    }
    constructor(_mainFile, _fallbackFile, fileSystem, maximumBreadcrumbs) {
        this._mainFile = _mainFile;
        this._fallbackFile = _fallbackFile;
        this._lastBreadcrumbId = sdk_core_1.TimeHelper.toTimestampInSec(sdk_core_1.TimeHelper.now());
        this._writer = new AlternatingFileWriter_1.AlternatingFileWriter(_mainFile, _fallbackFile, Math.floor(maximumBreadcrumbs / 2), fileSystem);
    }
    static createFromSession(session, fileSystem) {
        const files = session
            .getSessionFiles()
            .filter((f) => path_1.default.basename(f).startsWith(FILE_PREFIX))
            .slice(0, 2);
        if (!files.length) {
            return undefined;
        }
        return new FileBreadcrumbsStorage(files[0], files[1], fileSystem, 1);
    }
    static create(session, fileSystem, maximumBreadcrumbs) {
        const file1 = session.getFileName(this.getFileName(0));
        const file2 = session.getFileName(this.getFileName(1));
        return new FileBreadcrumbsStorage(file1, file2, fileSystem, maximumBreadcrumbs);
    }
    getAttachments() {
        return [
            new attachment_1.BacktraceFileAttachment(this._mainFile, 'bt-breadcrumbs-0'),
            new attachment_1.BacktraceFileAttachment(this._fallbackFile, 'bt-breadcrumbs-1'),
        ];
    }
    add(rawBreadcrumb) {
        this._lastBreadcrumbId++;
        const id = this._lastBreadcrumbId;
        const breadcrumb = {
            id,
            message: rawBreadcrumb.message,
            timestamp: sdk_core_1.TimeHelper.now(),
            type: sdk_core_1.BreadcrumbType[rawBreadcrumb.type].toLowerCase(),
            level: sdk_core_1.BreadcrumbLogLevel[rawBreadcrumb.level].toLowerCase(),
            attributes: rawBreadcrumb.attributes,
        };
        const breadcrumbJson = JSON.stringify(breadcrumb, (0, sdk_core_1.jsonEscaper)());
        this._writer.writeLine(breadcrumbJson);
        return id;
    }
    static getFileName(index) {
        return `${FILE_PREFIX}-${index}`;
    }
}
exports.FileBreadcrumbsStorage = FileBreadcrumbsStorage;


/***/ }),

/***/ 457:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.BacktraceClientBuilder = void 0;
const sdk_core_1 = __webpack_require__(668);
const transformAttachments_1 = __webpack_require__(781);
const attributes_1 = __webpack_require__(816);
const BacktraceClient_1 = __webpack_require__(62);
class BacktraceClientBuilder extends sdk_core_1.BacktraceCoreClientBuilder {
    constructor(clientSetup) {
        var _a;
        super(Object.assign(Object.assign({}, clientSetup), { options: Object.assign(Object.assign({}, clientSetup.options), { attachments: (_a = clientSetup.options.attachments) === null || _a === void 0 ? void 0 : _a.map(transformAttachments_1.transformAttachment) }) }));
        this.addAttributeProvider(new attributes_1.ApplicationInformationAttributeProvider());
        this.addAttributeProvider(new attributes_1.ProcessStatusAttributeProvider());
        this.addAttributeProvider(new attributes_1.MachineAttributeProvider());
        this.addAttributeProvider(new attributes_1.ProcessInformationAttributeProvider());
        this.addAttributeProvider(new attributes_1.LinuxProcessStatusAttributeProvider());
        this.addAttributeProvider(new attributes_1.MachineIdentitfierAttributeProvider());
    }
    build() {
        const instance = new BacktraceClient_1.BacktraceClient(this.clientSetup);
        instance.initialize();
        return instance;
    }
}
exports.BacktraceClientBuilder = BacktraceClientBuilder;


/***/ }),

/***/ 93:
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));


/***/ }),

/***/ 636:
/***/ (function(__unused_webpack_module, exports) {


var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.AlternatingFileWriter = void 0;
class AlternatingFileWriter {
    constructor(_mainFile, _fallbackFile, _fileCapacity, _fileSystem) {
        this._mainFile = _mainFile;
        this._fallbackFile = _fallbackFile;
        this._fileCapacity = _fileCapacity;
        this._fileSystem = _fileSystem;
        this._count = 0;
        this._disposed = false;
    }
    writeLine(value) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this._fileCapacity <= 0) {
                return this;
            }
            if (this._disposed) {
                throw new Error('This instance has been disposed.');
            }
            if (!this._fileStream) {
                const stream = this.safeCreateStream(this._mainFile);
                if (!stream) {
                    return this;
                }
                this._fileStream = stream;
            }
            else if (this._count >= this._fileCapacity) {
                this._fileStream.close();
                this.safeMoveMainToFallback();
                this._count = 0;
                const stream = this.safeCreateStream(this._mainFile);
                if (!stream) {
                    return this;
                }
                this._fileStream = stream;
            }
            yield this.safeWriteAsync(this._fileStream, value + '\n');
            this._count++;
            return this;
        });
    }
    safeWriteAsync(fs, data) {
        return new Promise((resolve) => fs.write(data, (err) => (err ? resolve(false) : resolve(true))));
    }
    dispose() {
        var _a;
        (_a = this._fileStream) === null || _a === void 0 ? void 0 : _a.close();
        this._disposed = true;
    }
    safeCreateStream(path) {
        try {
            return this._fileSystem.createWriteStream(path);
        }
        catch (_a) {
            return undefined;
        }
    }
    safeMoveMainToFallback() {
        try {
            this._fileSystem.renameSync(this._mainFile, this._fallbackFile);
            return true;
        }
        catch (_a) {
            return false;
        }
    }
}
exports.AlternatingFileWriter = AlternatingFileWriter;


/***/ }),

/***/ 726:
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.NodeOptionReader = void 0;
class NodeOptionReader {
    /**
     * Read option based on the option name. If the option doesn't start with `--`
     * additional prefix will be added.
     * @param optionName option name
     * @returns option value
     */
    static read(optionName, argv = process.execArgv, nodeOptions = process.env['NODE_OPTIONS']) {
        /**
         * exec argv overrides NODE_OPTIONS.
         * for example:
         * yarn start = NODEW_ENV=production node --unhandled-rejections=none ./lib/index.js
         * NODE_OPTIONS='--unhandled-rejections=throw' yarn start
         *
         * Even if NODE_OPTIONS have unhandled rejections set to throw, the value passed in argv
         * will be used.
         */
        if (!optionName.startsWith('--')) {
            optionName = '--' + optionName;
        }
        const commandOption = argv.find((n) => n.startsWith(optionName));
        function readOptionValue(optionName, commandOption) {
            let result = commandOption.substring(optionName.length);
            if (!result) {
                return true;
            }
            if (result.startsWith('=')) {
                result = result.substring(1);
            }
            return result;
        }
        if (commandOption) {
            return readOptionValue(optionName, commandOption);
        }
        if (!nodeOptions) {
            return undefined;
        }
        const nodeOption = nodeOptions.split(' ').find((n) => n.startsWith(optionName));
        if (!nodeOption) {
            return undefined;
        }
        return readOptionValue(optionName, nodeOption);
    }
}
exports.NodeOptionReader = NodeOptionReader;


/***/ }),

/***/ 230:
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.UnitConverter = void 0;
class UnitConverter {
    static parseKb(str) {
        return parseInt(str, 10) * 1024;
    }
}
exports.UnitConverter = UnitConverter;


/***/ }),

/***/ 745:
/***/ ((__unused_webpack_module, exports, __webpack_require__) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.NodeDiagnosticReportConverter = void 0;
const sdk_core_1 = __webpack_require__(668);
class NodeDiagnosticReportConverter {
    convert(report) {
        const jsStack = report.javascriptStack.stack;
        const validJsStack = jsStack && jsStack[0] !== 'Unavailable.';
        const message = validJsStack ? report.javascriptStack.message : report.header.event;
        const btReport = new sdk_core_1.BacktraceReport(message, Object.assign(Object.assign(Object.assign(Object.assign({ hostname: report.header.host }, this.getUnameData(report)), this.getCpuData(report)), this.getMemoryData(report)), { 
            // Annotations
            'Environment Variables': report.environmentVariables, 'Exec Arguments': report.header.commandLine, Error: report }), [], {
            timestamp: parseInt(report.header.dumpEventTimeStamp),
            classifiers: [report.header.trigger],
        });
        if (validJsStack) {
            btReport.addStackTrace('main', jsStack.join('\n'));
        }
        const nativeStack = report.nativeStack;
        if (nativeStack) {
            const nativeFrames = nativeStack.map((frame) => ({
                funcName: frame.symbol,
                library: 'v8',
            }));
            // If the JS stack is valid, add as 'native', otherwise 'main'
            const threadName = validJsStack ? 'native' : 'main';
            btReport.addStackTrace(threadName, nativeFrames);
        }
        const isOom = report.header.event === 'Allocation failed - JavaScript heap out of memory';
        const errorType = isOom ? 'OOMException' : 'Crash';
        btReport.attributes['error.type'] = errorType;
        return btReport;
    }
    getUnameData(report) {
        return {
            'uname.sysname': report.header.osName,
            'uname.release': report.header.osRelease,
            'uname.version': report.header.osVersion,
            'uname.machine': report.header.osMachine,
        };
    }
    getCpuData(report) {
        const cpu = report.header.cpus[0];
        return {
            'cpu.arch': report.header.arch,
            'cpu.brand': cpu.model,
            'cpu.frequency': cpu.speed,
            'cpu.user': cpu.user,
            'cpu.nice': cpu.nice,
            'cpu.sys': cpu.sys,
            'cpu.idle': cpu.idle,
            'cpu.irq': cpu.irq,
            'cpu.count': report.header.cpus.length,
        };
    }
    getMemoryData(report) {
        return {
            'vm.rss.size': Math.round(report.javascriptHeap.usedMemory / 1024),
            'vm.rss.peak': Math.round(report.javascriptHeap.totalMemory / 1024),
            'vm.rss.available': report.javascriptHeap.availableMemory,
        };
    }
}
exports.NodeDiagnosticReportConverter = NodeDiagnosticReportConverter;


/***/ }),

/***/ 920:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.BreadcrumbsManager = exports.BreadcrumbType = exports.BreadcrumbLogLevel = exports.BacktraceReport = void 0;
var sdk_core_1 = __webpack_require__(668);
Object.defineProperty(exports, "BacktraceReport", ({ enumerable: true, get: function () { return sdk_core_1.BacktraceReport; } }));
Object.defineProperty(exports, "BreadcrumbLogLevel", ({ enumerable: true, get: function () { return sdk_core_1.BreadcrumbLogLevel; } }));
Object.defineProperty(exports, "BreadcrumbType", ({ enumerable: true, get: function () { return sdk_core_1.BreadcrumbType; } }));
Object.defineProperty(exports, "BreadcrumbsManager", ({ enumerable: true, get: function () { return sdk_core_1.BreadcrumbsManager; } }));
__exportStar(__webpack_require__(62), exports);
__exportStar(__webpack_require__(47), exports);
__exportStar(__webpack_require__(353), exports);
__exportStar(__webpack_require__(577), exports);
__exportStar(__webpack_require__(457), exports);
__exportStar(__webpack_require__(93), exports);


/***/ }),

/***/ 558:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.FsNodeFileSystem = void 0;
const fs_1 = __importDefault(__webpack_require__(147));
const attachment_1 = __webpack_require__(577);
class FsNodeFileSystem {
    readDir(dir) {
        return fs_1.default.promises.readdir(dir);
    }
    readDirSync(dir) {
        return fs_1.default.readdirSync(dir);
    }
    createDir(dir) {
        return fs_1.default.promises.mkdir(dir, { recursive: true });
    }
    createDirSync(dir) {
        fs_1.default.mkdirSync(dir, { recursive: true });
    }
    readFile(path) {
        return fs_1.default.promises.readFile(path, 'utf-8');
    }
    readFileSync(path) {
        return fs_1.default.readFileSync(path, 'utf-8');
    }
    writeFile(path, content) {
        return fs_1.default.promises.writeFile(path, content);
    }
    writeFileSync(path, content) {
        fs_1.default.writeFileSync(path, content);
    }
    unlink(path) {
        return fs_1.default.promises.unlink(path);
    }
    unlinkSync(path) {
        fs_1.default.unlinkSync(path);
    }
    rename(oldPath, newPath) {
        return fs_1.default.promises.rename(oldPath, newPath);
    }
    renameSync(oldPath, newPath) {
        fs_1.default.renameSync(oldPath, newPath);
    }
    createWriteStream(path) {
        const stream = fs_1.default.createWriteStream(path, 'utf-8');
        stream.writeSync = (chunk) => stream.write(chunk);
        return stream;
    }
    exists(path) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield fs_1.default.promises.stat(path);
                return true;
            }
            catch (_a) {
                return false;
            }
        });
    }
    existsSync(path) {
        return fs_1.default.existsSync(path);
    }
    createAttachment(path, name) {
        return new attachment_1.BacktraceFileAttachment(path, name);
    }
}
exports.FsNodeFileSystem = FsNodeFileSystem;


/***/ }),

/***/ 668:
/***/ ((module) => {

module.exports = require("@backtrace/sdk-core");

/***/ }),

/***/ 941:
/***/ ((module) => {

module.exports = require("form-data");

/***/ }),

/***/ 877:
/***/ ((module) => {

module.exports = require("native-reg");

/***/ }),

/***/ 369:
/***/ ((module) => {

module.exports = require("process");

/***/ }),

/***/ 81:
/***/ ((module) => {

module.exports = require("child_process");

/***/ }),

/***/ 147:
/***/ ((module) => {

module.exports = require("fs");

/***/ }),

/***/ 685:
/***/ ((module) => {

module.exports = require("http");

/***/ }),

/***/ 687:
/***/ ((module) => {

module.exports = require("https");

/***/ }),

/***/ 37:
/***/ ((module) => {

module.exports = require("os");

/***/ }),

/***/ 17:
/***/ ((module) => {

module.exports = require("path");

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = __webpack_module_cache__;
/******/ 	
/************************************************************************/
/******/ 	
/******/ 	// module cache are used so entry inlining is disabled
/******/ 	// startup
/******/ 	// Load entry module and return exports
/******/ 	var __webpack_exports__ = __webpack_require__(__webpack_require__.s = 920);
/******/ 	module.exports = __webpack_exports__;
/******/ 	
/******/ })()
;
//# sourceMappingURL=index.js.map