"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InMemoryBreadcrumbsStorage = void 0;
const jsonEscaper_1 = require("../../../common/jsonEscaper");
const TimeHelper_1 = require("../../../common/TimeHelper");
const OverwritingArray_1 = require("../../../dataStructures/OverwritingArray");
const BreadcrumbLogLevel_1 = require("../model/BreadcrumbLogLevel");
const BreadcrumbType_1 = require("../model/BreadcrumbType");
class InMemoryBreadcrumbsStorage {
    get lastBreadcrumbId() {
        return this._lastBreadcrumbId;
    }
    constructor(maximumBreadcrumbs = 100) {
        /**
         * Breadcrumb name
         */
        this.name = 'bt-breadcrumbs-0';
        this._lastBreadcrumbId = TimeHelper_1.TimeHelper.toTimestampInSec(TimeHelper_1.TimeHelper.now());
        this._breadcrumbs = new OverwritingArray_1.OverwritingArray(maximumBreadcrumbs);
    }
    getAttachments() {
        return [this];
    }
    /**
     * Returns breadcrumbs in the JSON format
     * @returns Breadcrumbs JSON
     */
    get() {
        return JSON.stringify([...this._breadcrumbs.values()], (0, jsonEscaper_1.jsonEscaper)());
    }
    add(rawBreadcrumb) {
        this._lastBreadcrumbId++;
        const id = this._lastBreadcrumbId;
        const breadcrumb = {
            id,
            message: rawBreadcrumb.message,
            timestamp: TimeHelper_1.TimeHelper.now(),
            type: BreadcrumbType_1.BreadcrumbType[rawBreadcrumb.type].toLowerCase(),
            level: BreadcrumbLogLevel_1.BreadcrumbLogLevel[rawBreadcrumb.level].toLowerCase(),
        };
        if (rawBreadcrumb.attributes) {
            breadcrumb.attributes = rawBreadcrumb.attributes;
        }
        this._breadcrumbs.add(breadcrumb);
        return id;
    }
}
exports.InMemoryBreadcrumbsStorage = InMemoryBreadcrumbsStorage;
//# sourceMappingURL=InMemoryBreadcrumbsStorage.js.map