"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BacktraceDataBuilder = void 0;
const IdGenerator_1 = require("../../common/IdGenerator");
const TimeHelper_1 = require("../../common/TimeHelper");
const ReportDataBuilder_1 = require("../attribute/ReportDataBuilder");
class BacktraceDataBuilder {
    constructor(_sdkOptions, _stackTraceConverter, _attributeManager, _debugIdProvider) {
        this._sdkOptions = _sdkOptions;
        this._stackTraceConverter = _stackTraceConverter;
        this._attributeManager = _attributeManager;
        this._debugIdProvider = _debugIdProvider;
        this.MAIN_THREAD_NAME = 'main';
    }
    build(report) {
        const { annotations, attributes } = this._attributeManager.get();
        const reportData = ReportDataBuilder_1.ReportDataBuilder.build(report.attributes);
        const { threads, detectedDebugIdentifier } = this.getThreads(report);
        const result = {
            uuid: IdGenerator_1.IdGenerator.uuid(),
            timestamp: TimeHelper_1.TimeHelper.toTimestampInSec(report.timestamp),
            agent: this._sdkOptions.agent,
            agentVersion: this._sdkOptions.agentVersion,
            lang: this._sdkOptions.langName,
            langVersion: this._sdkOptions.langVersion,
            classifiers: report.classifiers,
            mainThread: this.MAIN_THREAD_NAME,
            threads,
            annotations: Object.assign(Object.assign(Object.assign({}, annotations), reportData.annotations), report.annotations),
            attributes: Object.assign(Object.assign({}, attributes), reportData.attributes),
        };
        if (detectedDebugIdentifier) {
            result.symbolication = 'sourcemap';
        }
        return result;
    }
    getThreads(report) {
        const threads = {};
        let detectedDebugIdentifier = false;
        for (const [name, traceInfo] of Object.entries(report.stackTrace)) {
            let stackFrames;
            if (Array.isArray(traceInfo)) {
                stackFrames = traceInfo;
            }
            else {
                const { message, stack } = traceInfo;
                stackFrames = this._stackTraceConverter.convert(stack, message);
            }
            if (name === this.MAIN_THREAD_NAME && report.skipFrames > 0) {
                stackFrames.splice(0, report.skipFrames);
            }
            for (const frame of stackFrames) {
                const debugIdentifier = this._debugIdProvider.getDebugId(frame.library);
                if (!debugIdentifier) {
                    continue;
                }
                detectedDebugIdentifier = true;
                frame.debug_identifier = debugIdentifier;
            }
            threads[name] = {
                fault: name === this.MAIN_THREAD_NAME,
                name,
                stack: stackFrames,
            };
        }
        return {
            threads,
            detectedDebugIdentifier,
        };
    }
}
exports.BacktraceDataBuilder = BacktraceDataBuilder;
//# sourceMappingURL=BacktraceDataBuilder.js.map