"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RateLimitWatcher = void 0;
const TimeHelper_1 = require("../../common/TimeHelper");
class RateLimitWatcher {
    get enabled() {
        return this._watcherEnable;
    }
    constructor(reportPerMin) {
        /**
         * Time the single report can stay in the queue in ms.
         */
        this.MAXIMUM_TIME_IN_QUEUE = 60 * 1000;
        this._reportQueue = [];
        if (reportPerMin == null) {
            reportPerMin = 0;
        }
        if (reportPerMin < 0) {
            throw new Error('ReportPerMinute argument must be greater or equal to zero');
        }
        this._reportPerMin = reportPerMin;
        this._watcherEnable = reportPerMin > 0;
    }
    skipReport() {
        const time = TimeHelper_1.TimeHelper.now();
        if (!this._watcherEnable) {
            return false;
        }
        this.clear(time);
        if (this._reportQueue.length >= this._reportPerMin) {
            return true;
        }
        this._reportQueue.push(time);
        return false;
    }
    clear(time) {
        if (this._reportQueue.length === 0) {
            return;
        }
        // we don't have anything to remove
        if (time - this._reportQueue[0] < this.MAXIMUM_TIME_IN_QUEUE) {
            return;
        }
        for (let queueIndex = this._reportQueue.length; queueIndex != 0; queueIndex--) {
            if (time - this._reportQueue[queueIndex - 1] > this.MAXIMUM_TIME_IN_QUEUE) {
                this._reportQueue = this._reportQueue.slice(queueIndex);
                return;
            }
        }
    }
}
exports.RateLimitWatcher = RateLimitWatcher;
//# sourceMappingURL=RateLimitWatcher.js.map