"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DebugIdProvider = exports.SOURCE_DEBUG_ID_VARIABLE = void 0;
exports.SOURCE_DEBUG_ID_VARIABLE = '_btDebugIds';
class DebugIdProvider {
    constructor(_stackTraceConverter, _debugIdMapProvider) {
        this._stackTraceConverter = _stackTraceConverter;
        this._debugIdMapProvider = _debugIdMapProvider;
        this._fileDebugIds = this.loadDebugIds();
    }
    getDebugId(file) {
        const debugId = this._fileDebugIds[file];
        if (debugId) {
            return debugId;
        }
        // in case of dynamic require - lazy load dynamically debug ids
        this._fileDebugIds = this.loadDebugIds();
        return this._fileDebugIds[file];
    }
    loadDebugIds() {
        var _a;
        const debugIdMap = (_a = this._debugIdMapProvider) === null || _a === void 0 ? void 0 : _a.getDebugIdMap();
        if (!debugIdMap) {
            return {};
        }
        const message = new Error().message;
        const result = {};
        for (const [rawStack, debugId] of Object.entries(debugIdMap)) {
            const frames = this._stackTraceConverter.convert(rawStack, message);
            if (!frames.length) {
                continue;
            }
            // The first frame will have the file's path
            const frame = frames[0];
            result[frame.library] = debugId;
        }
        return result;
    }
}
exports.DebugIdProvider = DebugIdProvider;
//# sourceMappingURL=DebugIdProvider.js.map